/**
 * Resources:
 * https://stackoverflow.com/questions/76131891/what-is-the-best-method-for-socket-io-authentication
 *
 */

import {Application, Request, Response} from 'express';
import UserService from '../services/UserService';
import jwt from "jsonwebtoken";
import config from "./Config";

async function addAuthRoutes(app: Application) {
    app.post('/login', async (req: Request, res: Response) => {
        const { username, password } = req.body;

        const userService = new UserService();
        const user = await userService.login(username, password);

        if (user) {
            const token = jwt.sign({ id: user.id }, config.JWT_SECRET, { expiresIn: '1h' });
            return res.status(200).json({ token });
        }
        return res.status(401).json({ message: 'Invalid credentials' });
    });

    app.post('/register', async (req: Request, res: Response) => {
        const { username, password } = req.body;

        const userService = new UserService();
        const user = await userService.register(username, password);

        if (user) {
            const token = jwt.sign({ id: user.id }, config.JWT_SECRET, { expiresIn: '1h' });
            return res.status(201).json({ token });
        }
        return res.status(400).json({ message: 'Failed to register user' });
    });

    console.log('[✅] Auth routes added');
}

export { addAuthRoutes };